@@ -4,7 +4,13 @@ Datasets, etc. for timeseries data.
 Handling timeseries data is not trivial. It requires special treatment. This sub-package provides the necessary tools
 to abstracts the necessary work.
 """
-from pytorch_forecasting.data.encoders import EncoderNormalizer, GroupNormalizer, NaNLabelEncoder, TorchNormalizer
+from pytorch_forecasting.data.encoders import (
+    EncoderNormalizer,
+    GroupNormalizer,
+    MultiNormalizer,
+    NaNLabelEncoder,
+    TorchNormalizer,
+)
 from pytorch_forecasting.data.timeseries import TimeSeriesDataSet, TimeSynchronizedBatchSampler
 
 __all__ = [
@@ -14,4 +20,5 @@ __all__ = [
     "TorchNormalizer",
     "EncoderNormalizer",
     "TimeSynchronizedBatchSampler",
+    "MultiNormalizer",
 ]
