@@ -120,14 +120,27 @@ class Ranger(Optimizer):
         # for w in it.chain(*self.slow_weights):
         #    w.requires_grad = False
 
+    def __getstate__(self) -> dict:
+        state = super().__getstate__()
+        state["radam_buffer"] = self.radam_buffer
+        state["alpha"] = self.alpha
+        state["k"] = self.k
+        state["N_sma_threshhold"] = self.N_sma_threshhold
+        return state
+
     def __setstate__(self, state: dict) -> None:
         super().__setstate__(state)
+        self.radam_buffer = state["radam_buffer"]
+        self.alpha = state["alpha"]
+        self.k = state["k"]
+        self.N_sma_threshhold = state["N_sma_threshhold"]
 
     def step(self, closure: OptLossClosure = None) -> OptFloat:
         r"""Performs a single optimization step.
         Arguments:
             closure: A closure that reevaluates the model and returns the loss.
         """
+        _ = closure()
         loss = None
         # note - below is commented out b/c I have other work that passes back
         # the loss as a float, and thus not a callable closure.
